from .santamonica_scraper_models import Committee


def seed_tables(Session):
    session = Session()
    if len(session.query(Committee).all()) == 0:
        session.add(Committee(name="Santa Monica City Council",
                              email="engage@engage.town",
                              cutoff_offset_days=0,
                              cutoff_hour=12,
                              cutoff_minute=0
                              ))
        session.commit()


from bs4 import BeautifulSoup

def bs4_data_from_url(url, session, method, data=None):
    """
    Helper, common task
    """
    if method == "GET":
        r = session.get(url)
    else:
        r = session.post(url, data=data)
    
    soup = BeautifulSoup(r.text, 'html.parser')
    return soup

def parse_query_params(url):
    '''
    Takes the split key value pairs which are made up of ["key=value", "key=value", "key="]
    value may be empty except for MeetingID and ID keys
    Returns a dictionary with two keys "MeetingID" and "ID"
    Values are already split on &
    '''
    params = url.split("?")[1].strip().split("&")
    if len(params) == 0:
        raise IndexError
    query = dict()
    for param in params:
        split_param = param.split("=")
        query[split_param[0].strip()] = split_param[1].strip()
    return query

def check_style_special(inline_style_string):
    if "bold" in inline_style_string:
        return True
    if "underline" in inline_style_string:
        return True
    return False



def check_last_word(string_data):
    last_word = string_data.split(" ")[-1]
    if len(last_word) == 1 and last_word.lower() not in ["i", "a"]:
        return False
    elif len(last_word) == 2 and last_word.lower() not in ["an", "or", "if", "it", "as", "to"]:
        return False
    return True


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="engage_scraper",
    version="0.0.34",
    author="Engage",
    author_email="eli.j.selkin@gmail.com",
    description="An agenda scraper framework for municipalities",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/hackla-engage/engage-scraper",
    packages=setuptools.find_packages(),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'soupsieve',
        'beautifulsoup4',
        'psycopg2-binary',
        'pytz',
        'requests',
        'SQLAlchemy',
        'urllib3', 
        'python-twitter']
)
